# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.models.setup_flow_status import SetupFlowStatus

class TestSetupFlowStatus(unittest.TestCase):
    """SetupFlowStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSetupFlowStatus(self):
        """Test SetupFlowStatus"""
        # inst = SetupFlowStatus()

if __name__ == '__main__':
    unittest.main()
