# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.payment_flows_api import PaymentFlowsApi


class TestPaymentFlowsApi(unittest.TestCase):
    """PaymentFlowsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PaymentFlowsApi()

    def tearDown(self) -> None:
        pass

    def test_cancel_payment_flow(self) -> None:
        """Test case for cancel_payment_flow

        Cancel Payment Flow
        """
        pass

    def test_capture_payment_flow(self) -> None:
        """Test case for capture_payment_flow

        Capture Payment Flow
        """
        pass

    def test_confirm_payment_flow(self) -> None:
        """Test case for confirm_payment_flow

        Confirm Payment Flow
        """
        pass

    def test_create_payment_flow(self) -> None:
        """Test case for create_payment_flow

        Create Payment Flow
        """
        pass

    def test_get_all_payment_flows(self) -> None:
        """Test case for get_all_payment_flows

        Get All Payment Flows
        """
        pass

    def test_get_payment_flow(self) -> None:
        """Test case for get_payment_flow

        Get Payment Flow
        """
        pass

    def test_get_payment_flow_refunds(self) -> None:
        """Test case for get_payment_flow_refunds

        Get Payment Flow Refunds
        """
        pass

    def test_update_payment_flow(self) -> None:
        """Test case for update_payment_flow

        Update Payment Flow
        """
        pass


if __name__ == '__main__':
    unittest.main()
