# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from payjpv2.api.customers_api import CustomersApi


class TestCustomersApi(unittest.TestCase):
    """CustomersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CustomersApi()

    def tearDown(self) -> None:
        pass

    def test_create_customer(self) -> None:
        """Test case for create_customer

        Create Customer
        """
        pass

    def test_delete_customer(self) -> None:
        """Test case for delete_customer

        Delete Customer
        """
        pass

    def test_get_all_customers(self) -> None:
        """Test case for get_all_customers

        Get All Customers
        """
        pass

    def test_get_customer(self) -> None:
        """Test case for get_customer

        Get Customer
        """
        pass

    def test_get_customer_payment_methods(self) -> None:
        """Test case for get_customer_payment_methods

        Get Customer Payment Methods
        """
        pass

    def test_update_customer(self) -> None:
        """Test case for update_customer

        Update Customer
        """
        pass


if __name__ == '__main__':
    unittest.main()
