# coding: utf-8

"""
    PAY.JP API v2

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 2.0.0
    Contact: support@pay.jp
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from payjpv2.models.currency import Currency
from payjpv2.models.metadata_value import MetadataValue
from payjpv2.models.price_type import PriceType
from typing import Optional, Set
from typing_extensions import Self

class PriceDetailsResponse(BaseModel):
    """
    PriceDetailsResponse
    """ # noqa: E501
    object: Optional[StrictStr] = 'price'
    id: StrictStr = Field(description="料金 ID")
    livemode: StrictBool = Field(description="本番環境かどうか")
    product_id: StrictStr = Field(description="この価格が紐付く商品の ID")
    unit_amount: StrictInt = Field(description="価格の単価")
    currency: Currency = Field(description="価格の通貨。現在は `jpy` のみサポートしています。")
    active: StrictBool = Field(description="価格が有効かどうか")
    nickname: Optional[StrictStr]
    type: PriceType = Field(description="一度限りの購入を表す `one_time` が入ります。")
    lookup_key: Optional[StrictStr]
    metadata: Dict[str, MetadataValue] = Field(description="メタデータ")
    created_at: datetime = Field(description="作成日時 (UTC, ISO 8601 形式)")
    updated_at: datetime = Field(description="更新日時 (UTC, ISO 8601 形式)")
    __properties: ClassVar[List[str]] = ["object", "id", "livemode", "product_id", "unit_amount", "currency", "active", "nickname", "type", "lookup_key", "metadata", "created_at", "updated_at"]

    @field_validator('object')
    def object_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['price']):
            raise ValueError("must be one of enum values ('price')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.model_dump(by_alias=True, exclude_unset=True))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PriceDetailsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in metadata (dict)
        _field_dict = {}
        if self.metadata:
            for _key_metadata in self.metadata:
                if self.metadata[_key_metadata]:
                    _field_dict[_key_metadata] = self.metadata[_key_metadata].to_dict()
            _dict['metadata'] = _field_dict
        # set to None if nickname (nullable) is None
        # and model_fields_set contains the field
        if self.nickname is None and "nickname" in self.model_fields_set:
            _dict['nickname'] = None

        # set to None if lookup_key (nullable) is None
        # and model_fields_set contains the field
        if self.lookup_key is None and "lookup_key" in self.model_fields_set:
            _dict['lookup_key'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PriceDetailsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "object": obj.get("object") if obj.get("object") is not None else 'price',
            "id": obj.get("id"),
            "livemode": obj.get("livemode"),
            "product_id": obj.get("product_id"),
            "unit_amount": obj.get("unit_amount"),
            "currency": obj.get("currency"),
            "active": obj.get("active"),
            "nickname": obj.get("nickname"),
            "type": obj.get("type"),
            "lookup_key": obj.get("lookup_key"),
            "metadata": dict(
                (_k, MetadataValue.from_dict(_v))
                for _k, _v in obj["metadata"].items()
            )
            if obj.get("metadata") is not None
            else None,
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj


